@@ -1,10 +1,11 @@
-/* Copyright (c) 2002-2017 Dovecot authors, see the included COPYING file
+/* Copyright (c) 2002-2018 Dovecot authors, see the included COPYING file
  */
 
 #ifndef PROGRAM_CLIENT_H
 #define PROGRAM_CLIENT_H
 
 #include "restrict-access.h"
+#include "net.h"
 
 struct program_client;
 
@@ -15,11 +16,18 @@ struct program_client_settings {
 	   restrict_access_init(&set.restrict_set);
 	*/
 	struct restrict_access_settings restrict_set;
+	const char *dns_client_socket_path;
 	const char *home;
 
 	bool allow_root:1;
 	bool debug:1;
 	bool drop_stderr:1;
+	/* use o_stream_dot, which is mainly useful to make sure that an
+	   unexpectedly closed connection doesn't cause the partial input to
+	   be accepted as valid and complete program input. This is always
+	   enabled for 'net' program clients, which may likely encounter
+	   unexpected connection termination. */
+	bool use_dotstream:1;
 };
 
 typedef void program_client_fd_callback_t(void *context, struct istream *input);
@@ -28,9 +36,17 @@ typedef void program_client_callback_t(int, void *);
 struct program_client *program_client_local_create(const char *bin_path,
 	const char *const *args,
 	const struct program_client_settings *set);
-struct program_client *program_client_remote_create(const char *socket_path,
+struct program_client *program_client_unix_create(const char *socket_path,
 	const char *const *args,
 	const struct program_client_settings *set, bool noreply);
+struct program_client *program_client_net_create(const char *host, in_port_t port,
+	const char *const *args,
+	const struct program_client_settings *set, bool noreply);
+struct program_client *
+program_client_net_create_ips(const struct ip_addr *ips, size_t ips_count,
+			      in_port_t port, const char *const *args,
+			      const struct program_client_settings *set,
+			      bool noreply);
 int program_client_create(const char *uri, const char *const *args,
 			  const struct program_client_settings *set,
 			  bool noreply, struct program_client **pc_r,
@@ -64,10 +80,11 @@ void program_client_set_env(struct program_client *pclient,
 /* Since script service cannot return system exit code, the exit value shall be
    -1, 0, or 1. -1 is internal error, 0 is failure and 1 is success */
 int program_client_run(struct program_client *pclient);
-void program_client_run_async(struct program_client *pclient, program_client_callback_t *, void*);
+void program_client_run_async(struct program_client *pclient,
+			      program_client_callback_t *, void*);
 #define program_client_run_async(pclient, callback, context) \
-	program_client_run_async(pclient, (program_client_callback_t*)callback, (char*)context + \
-		CALLBACK_TYPECHECK(callback, \
+	program_client_run_async(pclient, (program_client_callback_t*)callback, \
+		(char*)context + CALLBACK_TYPECHECK(callback, \
 			void (*)(int, typeof(context))))
 
 #endif
